// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018

// PROCESSING THE MASS PUBLIC SAMPLE
// Programmed by authors in Qualtrics and sampled by SSI in April 2016

// Code below takes many CSV (raw data from Qualtrics), cleans it, and turns it into data for analyis
// The below code does not have to be run on replication data because processing time can take several minutes, but it is included below to show how we processed the raw data from Qualtrics
// Because this data came from SSI, it is already deidentified

// 01 This do file takes the mass public survey data as a CSV, converts it to DTA, then recodes the randomizations in the vingette, and finally recodes the outcome measures (voting)

// OVERVIEW:
// The code starts by appending all surveys together from in-party vignette
// The experimental randomizations were not completed with JavaScript 
// Instead of JS, we use one master survey in Qualtrics that randomly selected one of many possible surveys all with different randomizations (the donors survey used JS and therefore does not have this complications)
// See the Excel doc. "Mass Public Survey Reference" for a summary located here: C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data\Block Group References
// The randomized treatment of "unusal" was included in the survey but not used in this paper. It is processed in these survey files but dropped in do file 3 after mass and donor surveys are combined.

// MORE DETAIL:
// The following code loops through each CSV file from each randomized survey and appends them all together. Then forms a DTA after all are insheeted.
// The loop takes in each csv, generates identifiers from the file name (including the issues used in the vigenette, PID of candidate, and candidate group).
// The loop then appends each subsequent file. NOTE: Because of the high number of survey CSV files, this process will take a eight minutes.
// Each CSV file is labeled by randomized treatment group where 1 = Aligned candidate, 2=Extreme Candidate, 3=Unusual (to be dropped because it is not used in this paper), and 4=Bipartisan 
// The second foreach var loop applies data labels to each variable (which is row 1) and then drops rows 1 which is now empty -> must be done before new append
// Minor detail: Groups 1 must be first merged serperatedly form Groups 2,3,4 because of v2096 and v1076 -> mismatch types variables from Qualtrics


/*

/////////////////////////////////////////////////
// PART 1:
// INSHEET APPENDS GROUP 1 TOGETHER 
/////////////////////////////////////////////////
set more off
clear
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"

local csvfiles: dir "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data\group 1" files "*.csv"
foreach file of local csvfiles {
 preserve
 clear
 insheet using "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data/group 1/`file'", names
 
 drop v2096 // empty qualtrics variable (Group 1) that breaks code from type mismatch (it's a blank byte for some reason)
 
 foreach var of varlist * {
  label variable `var' "`=`var'[1]'"
  replace `var'="" if _n==1
  destring `var', replace
}

 generate issue_treated = substr("`file'",18,6)
 generate pid_candidate = substr("`file'",9,3)
 generate group = substr("`file'",1,7)

 save temp, replace
 restore
 append using temp
}

// first row is empty now, so it needs to be dropped
drop if inlist(_n,1) 
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"
compress
save Mass_raw_group1, replace

use Mass_raw_group1
tab issue_treated

/////////////////////////////////////////////////
// PART 2:
// APPENDS GROUP 2,3, AND 4 TOGETHER 
/////////////////////////////////////////////////

cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"

clear
local csvfiles: dir "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data\group 2_3_4" files "*.csv"
foreach file of local csvfiles {
 preserve
 clear
 insheet using "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data/group 2_3_4/`file'", names
 
 drop v1076 // empty qualtrics variable (Group 1) that breaks code from type mismatch (it's a blank byte for some reason)
 
 foreach var of varlist * {
  label variable `var' "`=`var'[1]'"
  replace `var'="" if _n==1
  destring `var', replace
}

 generate issue_treated = substr("`file'",18,6)
 generate pid_candidate = substr("`file'",9,3)
 generate group = substr("`file'",1,7)

 save temp, replace
 restore
 append using temp
}

// first row is empty now, so it needs to be dropped
drop if inlist(_n,1) 

cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"
compress
save Mass_raw_group_2_3_4, replace

/////////////////////////////////////////////////
// PART3: 
// APPENDS GROUP 1 WITH GROUP 2,3,4 -> creates full dataset of in-party mass vignette
/////////////////////////////////////////////////

append using Mass_raw_group1

save Mass_raw_all_Respondents, replace
use Mass_raw_all_Respondents

// check identifiers (strings)
tab group // Which randomized candidate did they get?
tab issue_treated // What was their third issue area IF the candidate is not aligned?
tab pid_candidate // which candidate did the respondent see?

// drop test data with no psid -> these are us testing the link before launch and not actual respondents
drop if psid == ""


////////////////////////////////////
// PART 4: 
// RECODE ISSUE AREA AND POSITIONS VARIABLES
///////////////////////////////////////////////////////////////////////////////

// This part of the code identifies which issue areas and positions were randomly selected
// Because the current data file is a combo of many surveys with different Q names in each, we have to create indicators across a lot of questions

// (A)
// The "issue_treated" var is the one that indicates the third issue position IF it is not an aligned issue position
// This was picked up by the CSV file name in the loop

// This part of the code below takes that tag from the CSV file and turns it into a numeric variable
// If all the issues are aligned, they get code 99 (no issue was treated)
// 1 = Abortion, 2 = Guns, 3 = ISIS, 4 = Social Security, 5 = Taxes, 6 = Welfare (alphabetical order)

// Strings that note which issue is the 3rd treatment issue
gen issue_treatment = 99 // 99 means all issues are align
replace issue_treatment = 1 if issue_treated == "_abort"
replace issue_treatment = 1 if issue_treated == "ns_abo"
replace issue_treatment = 2 if issue_treated == "_guns_"
replace issue_treatment = 2 if issue_treated == "ns_gun"
replace issue_treatment = 3 if issue_treated == "_isis_"
replace issue_treatment = 3 if issue_treated == "ns_isi"
replace issue_treatment = 4 if issue_treated == "_socia"
replace issue_treatment = 4 if issue_treated == "ns_soc"
replace issue_treatment = 5 if issue_treated == "_taxes"
replace issue_treatment = 5 if issue_treated == "ns_tax"
replace issue_treatment = 6 if issue_treated == "_welfa"
replace issue_treatment = 6 if issue_treated == "ns_wel"
tab issue_treatment // numberic for which issue is treated
label var issue_treatment "Issue Area that is Treated"
label define issue_treatment_lab 1 "Abortion" 2 "Handguns" 3 "Fighting ISIS" 4 "Social Security" 5 "Income Taxes" 6 "Welfare" 99 "All Aligned"
label values issue_treatment issue_treatment_lab 
tab issue_treatment // numeric with data labels

//(B)
// indicators for which three issue areas were randomly selected (all issues in the vignette)
// Each survey contained a different combination of three issue areas
// The code notes which three issue areas were viewed by respondents
// Blocks were created to keep track of each issue area combination across the various surveys
// There are six issue areas, and each respondent sees 3 issue areas, so there are 20 possible combinations of blocks
// Each "if" condition looks for a response. If it is empty, that means the respondent did not complete that survey. 
// Each Q number after the "if" had to be check in Qualtrics to make sure it is the right survey. Also the data labels had to match the question wording

gen three_issues = ""

//block 1
replace three_issues = "G W I" if q1_16 != .
replace three_issues = "G W I" if q825_16 != .
replace three_issues = "G W I" if q873_16 != .
replace three_issues = "G W I" if q102_16 != .
replace three_issues = "G W I" if q826_16 != .
replace three_issues = "G W I" if q874_16 != .
//block 2
replace three_issues = "G W SS" if q921_16 != .
replace three_issues = "G W SS" if q969_16 != .
replace three_issues = "G W SS" if q1065_16 != .
replace three_issues = "G W SS" if q922_16 != .
replace three_issues = "G W SS" if q970_16 != .
replace three_issues = "G W SS" if q1066_16 != .
//block 3
replace three_issues = "G W Ab" if q1113_16 != .
replace three_issues = "G W Ab" if q1161_16 != .
replace three_issues = "G W Ab" if q1209_16 != .
replace three_issues = "G W Ab" if q1114_16 != .
replace three_issues = "G W Ab" if q1162_16 != .
replace three_issues = "G W Ab" if q1210_16 != .
//block 4
replace three_issues = "G W T" if q1257_16 != .
replace three_issues = "G W T" if q1305_16 != .
replace three_issues = "G W T" if q1353_16 != .
replace three_issues = "G W T" if q1258_16 != .
replace three_issues = "G W T" if q1306_16 != .
replace three_issues = "G W T" if q1354_16 != .
//block 5
replace three_issues = "G I SS" if q1401_16 != .
replace three_issues = "G I SS" if q1449_16 != .
replace three_issues = "G I SS" if q1497_16 != .
replace three_issues = "G I SS" if q1402_16 != .
replace three_issues = "G I SS" if q1450_16 != .
replace three_issues = "G I SS" if q1498_16 != .
//block 6
replace three_issues = "G I Ab" if q1593_16 != .
replace three_issues = "G I Ab" if q1641_16 != .
replace three_issues = "G I Ab" if q1689_16 != .
replace three_issues = "G I Ab" if q1594_16 != .
replace three_issues = "G I Ab" if q1642_16 != .
replace three_issues = "G I Ab" if q1690_16 != .
//block 7
replace three_issues = "G I T" if q1737_16 != .
replace three_issues = "G I T" if q1785_16 != .
replace three_issues = "G I T" if q1833_16 != .
replace three_issues = "G I T" if q1738_16 != .
replace three_issues = "G I T" if q1786_16 != .
replace three_issues = "G I T" if q1834_16 != .
//block 8
replace three_issues = "G SS Ab" if q1881_16 != .
replace three_issues = "G SS Ab" if q1929_16 != .
replace three_issues = "G SS Ab" if q1977_16 != .
replace three_issues = "G SS Ab" if q1882_16 != .
replace three_issues = "G SS Ab" if q1930_16 != .
replace three_issues = "G SS Ab" if q1978_16 != .
//block 9
replace three_issues = "G SS T" if q2025_16 != .
replace three_issues = "G SS T" if q2073_16 != .
replace three_issues = "G SS T" if q2121_16 != .
replace three_issues = "G SS T" if q2026_16 != .
replace three_issues = "G SS T" if q2074_16 != .
replace three_issues = "G SS T" if q2122_16 != .
//block 10
replace three_issues = "G Ab T" if q2169_16 != .
replace three_issues = "G Ab T" if q2217_16 != .
replace three_issues = "G Ab T" if q2265_16 != .
replace three_issues = "G Ab T" if q2170_16 != .
replace three_issues = "G Ab T" if q2218_16 != .
replace three_issues = "G Ab T" if q2266_16 != .
//block 11
replace three_issues = "W I SS" if q2313_16 != .
replace three_issues = "W I SS" if q2361_16 != .
replace three_issues = "W I SS" if q2409_16 != .
replace three_issues = "W I SS" if q2314_16 != .
replace three_issues = "W I SS" if q2362_16 != .
replace three_issues = "W I SS" if q2410_16 != .
//block 12
replace three_issues = "W I Ab" if q2457_16 != .
replace three_issues = "W I Ab" if q2505_16 != .
replace three_issues = "W I Ab" if q2553_16 != .
replace three_issues = "W I Ab" if q2458_16 != .
replace three_issues = "W I Ab" if q2506_16 != .
replace three_issues = "W I Ab" if q2554_16 != .
//block 13
replace three_issues = "W I T" if q2601_16 != .
replace three_issues = "W I T" if q2649_16 != .
replace three_issues = "W I T" if q2697_16 != .
replace three_issues = "W I T" if q2602_16 != .
replace three_issues = "W I T" if q2650_16 != .
replace three_issues = "W I T" if q2698_16 != .
//block 14
replace three_issues = "W SS Ab" if q2745_16 != .
replace three_issues = "W SS Ab" if q2793_16 != .
replace three_issues = "W SS Ab" if q2841_16 != .
replace three_issues = "W SS Ab" if q2746_16 != .
replace three_issues = "W SS Ab" if q2794_16 != .
replace three_issues = "W SS Ab" if q2842_16 != .
//block 15
replace three_issues = "W SS T" if q2889_16 != .
replace three_issues = "W SS T" if q2937_16 != .
replace three_issues = "W SS T" if q2985_16 != .
replace three_issues = "W SS T" if q2890_16 != .
replace three_issues = "W SS T" if q2938_16 != .
replace three_issues = "W SS T" if q2986_16 != .
//block 16
replace three_issues = "W Ab T" if q3033_16 != .
replace three_issues = "W Ab T" if q3081_16 != .
replace three_issues = "W Ab T" if q3129_16 != .
replace three_issues = "W Ab T" if q3034_16 != .
replace three_issues = "W Ab T" if q3082_16 != .
replace three_issues = "W Ab T" if q3130_16 != .
//block 17
replace three_issues = "I SS Ab" if q3177_16 != .
replace three_issues = "I SS Ab" if q3225_16 != .
replace three_issues = "I SS Ab" if q3273_16 != .
replace three_issues = "I SS Ab" if q3178_16 != .
replace three_issues = "I SS Ab" if q3226_16 != .
replace three_issues = "I SS Ab" if q3274_16 != .
replace three_issues = "I SS Ab" if q7945_16 != .
//block 18
replace three_issues = "I SS T" if q3321_16 != .
replace three_issues = "I SS T" if q3369_16 != .
replace three_issues = "I SS T" if q3417_16 != .
replace three_issues = "I SS T" if q3322_16 != .
replace three_issues = "I SS T" if q3370_16 != .
replace three_issues = "I SS T" if q3418_16 != .
//block 19
replace three_issues = "I Ab T" if q3465_16 != .
replace three_issues = "I Ab T" if q3513_16 != .
replace three_issues = "I Ab T" if q3609_16 != .
replace three_issues = "I Ab T" if q3466_16 != .
replace three_issues = "I Ab T" if q3514_16 != .
replace three_issues = "I Ab T" if q3610_16 != .
replace three_issues = "I Ab T" if q7969_16 ! =.
//block 20
replace three_issues = "SS Ab T" if q3657_16 != .
replace three_issues = "SS Ab T" if q3705_16 != .
replace three_issues = "SS Ab T" if q3753_16 != .
replace three_issues = "SS Ab T" if q3658_16 != .
replace three_issues = "SS Ab T" if q3706_16 != .
replace three_issues = "SS Ab T" if q3754_16 != .


// (C) Recodes the issue position by issue area

// GUNS
rename _1_d Guns_insert_aligned_dem_main
label var Guns_insert_aligned_dem_main "Randomized: Guns Position Aligned for Democrats"

rename _1_r Guns_insert_aligned_rep_main
label var Guns_insert_aligned_rep_main "Randomized: Guns Position Aligned for Republicans"

rename _2_d Guns_insert_extreme_dem_main
label var Guns_insert_extreme_dem_main "Randomized: Guns Position Extreme for Democrats"

rename _2_r Guns_insert_extreme_rep_main
label var Guns_insert_extreme_rep_main "Randomized: Guns Position Extreme for Republicans"

rename _3 Guns_insert_OE_main
label var Guns_insert_OE_main "Randomized: Guns Position Unusual for Both Parties"

// TAXES
rename v17 Taxes_insert_aligned_dem_main
label var Taxes_insert_aligned_dem_main "Randomized: Taxes Position Aligned for Democrats"

rename v18 Taxes_insert_aligned_rep_main
label var Taxes_insert_aligned_rep_main "Randomized: Taxes Position Aligned for Republicans"

rename v19 Taxes_insert_extreme_dem_main
label var Taxes_insert_extreme_dem_main "Randomized: Taxes Position Extreme for Democrats"

rename v20 Taxes_insert_extreme_rep_main
label var Taxes_insert_extreme_rep_main "Randomized: Taxes Position Extreme for Republicans"

rename v21 Taxes_insert_OE_main
label var Taxes_insert_OE_main "Randomized: Taxes Position Unusual for Both Parties"

// SOCIAL SECURITY
rename v22 SS_insert_aligned_dem_main
label var SS_insert_aligned_dem_main "Randomized: Social Security Position Aligned for Democrats"

rename v24 SS_insert_aligned_rep_main
label var SS_insert_aligned_rep_main "Randomized: Social Security Position Aligned for Republicans"

rename v25 SS_insert_extreme_dem_main
label var SS_insert_extreme_dem_main "Randomized: Social Security Position Extreme for Democrats"

rename v26 SS_insert_extreme_rep_main
label var SS_insert_extreme_rep_main "Randomized: Social Security Position Extreme for Republicans"

rename v27 SS_insert_OE_main
label var SS_insert_OE_main "Randomized: Social Security Position Unusual for Both Parties"

// ABORTION
rename v28 Abort_insert_aligned_dem_main
label var Abort_insert_aligned_dem_main "Randomized: Abortion Position Aligned for Democrats"

rename v29 Abort_insert_aligned_rep_main
label var Abort_insert_aligned_rep_main "Randomized: Abortion Position Aligned for Republicans"

rename v30 Abort_insert_extreme_dem_main
label var Abort_insert_extreme_dem_main "Randomized: Abortion Position Extreme for Democrats"

rename v31 Abort_insert_extreme_rep_main
label var Abort_insert_extreme_rep_main "Randomized: Abortion Position Extreme for Republicans"

rename v32 Abort_insert_OE_main
label var Abort_insert_OE_main "Randomized: Abortion Position Unusual for Both Parties"

// WELFARE
rename v33 Welfare_insert_aligned_dem_main
label var Welfare_insert_aligned_dem_main "Randomized: Welfare Position Aligned for Democrats"

rename v34 Welfare_insert_aligned_rep_main
label var Welfare_insert_aligned_rep_main "Randomized: Welfare Position Aligned for Republicans"

rename v35 Welfare_insert_extreme_dem_main
label var Welfare_insert_extreme_dem_main "Randomized: Welfare Position Extreme for Democrats"

rename v36 Welfare_insert_extreme_rep_main
label var Welfare_insert_extreme_rep_main "Randomized: Welfare Position Extreme for Republicans"

rename v37 Welfare_insert_OE_main
label var Welfare_insert_OE_main "Randomized: Welfare Position Unusual for Both Parties"

// ISIS
rename v38 ISIS_insert_aligned_dem_main
label var ISIS_insert_aligned_dem_main "Randomized: ISIS Position Aligned for Democrats"

rename v39 ISIS_insert_aligned_rep_main
label var ISIS_insert_aligned_rep_main "Randomized: ISIS Position Aligned for Republicans"

rename v40 ISIS_insert_extreme_dem_main
label var ISIS_insert_extreme_dem_main "Randomized: ISIS Position Extreme for Democrats"

rename v41 ISIS_insert_extreme_rep_main
label var ISIS_insert_extreme_rep_main "Randomized: ISIS Position Extreme for Republicans"

rename v42 ISIS_insert_OE_main
label var ISIS_insert_OE_main "Randomized: ISIS Position Unusual for Both Parties"


// ISSUE AREA INTRODUCTIONS
rename a guns_introduction
label var guns_introduction "Introductory statement for Handguns Issue Area"
rename v47 taxes_introduction
label var taxes_introduction "Introductory statement for Income Taxes Issue Area"
rename v48 social_security_introduction
label var social_security_introduction "Introductory statement for Social Security Issue Area"
rename v49 abortion_introduction
label var abortion_introduction "Introductory statement for Abortion Issue Area"
rename v50 welfare_introduction
label var welfare_introduction "Introductory statement for Welfare Issue Area"
rename v51 ISIS_introduction
label var ISIS_introduction "Introductory statement for ISIS Issue Area"


//////////////////////////////////////////////////////////////////////////////////////////////
// PART 5:
// RENAME RANDOMIZED INSERTS: ISSUES, MARKS OF COMPETENCY, AND COMPETITIVENESS OF ELECTION
//////////////////////////////////////////////////////////////////////////////////////////////

// This part of the code recode other randomized treatment conditions in the vignette
// These randomizations include competitivness of district, marks of competency 
// These had the same variable name across survey so there is only one var to recode

rename v43 district_competitiveness_main
label var district_competitiveness_main "Randomized: Competitiveness of Distrct"
rename v44 marks_of_competency_main 
label var marks_of_competency_main "Randomized: Marks of Competency"


///////////////////////////////////////////////////////////
//OUTCOME MEASURES ASKED OF THE MASS PUBLIC: VOTE CHOICE // 
///////////////////////////////////////////////////////////

// primary vote, likelihood of voting (0 to 100)
egen main_primary_vote = rowmax(q135_17 q862_17 q910_17 q958_17 q1006_17 q1102_17 q1150_17 q1198_17 q1246_17 q1294_17 q1342_17 q1390_17 q2350_17 q2398_17 q2446_17 q2494_17 q2542_17 q2590_17 q2638_17 q2686_17 q2734_17 q2782_17 q2830_17 ///
 q2878_17 q2926_17 q2974_17 q3022_17 q3070_17 q3118_17 q3166_17 q1774_17 q1822_17 q1870_17 q2062_17 q2110_17 q2158_17 q2206_17 q2254_17 q2302_17 q3358_17 q3406_17 q3454_17 q3502_17 q3550_17 q3646_17 ///
 q3694_17 q3742_17 q3790_17 q1438_17 q1486_17 q1534_17 q1918_17 q1966_17 q2014_17 q3214_17 q3262_17 q3310_17 q1630_17 q1678_17 q1726_17 q7962_17 q7986_17 q134_17 q859_17 q907_17 q955_17 q1003_17 q1095_17 q1099_17 ///
 q1147_17 q1195_17 q1243_17 q1291_17 q1339_17 q1387_17 q2347_17 q2395_17 q2443_17 q2491_17 q2539_17 q2587_17 q2635_17 q2683_17 q2731_17 q2779_17 q2827_17 q2875_17 q2923_17 q2971_17 q3019_17 q3067_17 q3115_17 ///
 q3163_17 q1771_17 q1819_17 q1867_17 q2059_17 q2107_17 q2155_17 q2203_17 q2251_17 q2299_17 q3355_17 q3403_17 q3451_17 q3499_17 q3547_17 q3643_17 q3691_17 q3739_17 q3787_17 q1435_17 q1483_17 q1531_17 q1915_17 ///
 q1963_17 q2011_17 q3211_17 q3259_17 q3307_17 q1627_17 q1675_17 q1723_17)
label var main_primary_vote "Primaries: Likelihood of Voting (0-100)"

// general vote, likelihood of voting (0 to 100)
egen main_general_vote = rowmax(q126_17 q869_17 q917_17 q965_17 q1013_17 q1109_17 q1157_17 q1205_17 q1253_17 q1301_17 q1349_17 q1397_17 q2357_17 q2405_17 q2453_17 q2501_17 q2549_17 q2597_17 q2645_17 q2693_17 ///
q2741_17 q2789_17 q2837_17 q2885_17 q2933_17 q2981_17 q3029_17 q3077_17 q3125_17 q3173_17 q1781_17 q1829_17 q1877_17 q2069_17 q2117_17 q2165_17 q2213_17 q2261_17 q2309_17 q3365_17 q3413_17 q3461_17 q3509_17 ///
q3557_17 q3653_17 q3701_17 q3749_17 q3797_17 q1445_17 q1493_17 q1541_17 q1925_17 q1973_17 q2021_17 q3221_17 q3269_17 q3317_17 q1637_17 q1685_17 q1733_17 q7965_17 q7989_17 q138_17 q865_17 q913_17 q961_17 ///
q1009_17 q1105_17 q1153_17 q1201_17 q1249_17 q1297_17 q1345_17 q1389_1 q2353_17 q2401_17 q2449_17 q2497_17 q2545_17 q2593_17 q2641_17 q2689_17 q2737_17 q2785_17 q2833_17 q2881_17 q2929_17 q2977_17 q3025_17 ///
q3073_17 q3121_17 q3169_17 q1777_17 q1825_17 q1873_17 q2065_17 q2113_17 q2161_17 q2209_17 q2257_17 q2305_17 q3361_17 q3409_17 q3457_17 q3505_17 q3553_17 q3649_17 q3697_17 q3745_17 q3793_17 q1441_17 q1489_17 ///
q1537_17 q1921_17 q1969_17 q2017_17 q3217_17 q3265_17 q3313_17 q1633_17 q1681_17 q1729_17)
label var main_general_vote "General: Likelihood of Voting (0-100)"


/////////////////////////////////////////////////
// PART 6: 
// Save Survey results up to this point
/////////////////////////////////////////////////

cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"
compress
save main_module_all_groups, replace


/////////////////////////////////////////////////
// PART 7: 
// In sheet Party ID survey with Demographic surveys
/////////////////////////////////////////////////

// Insheet Demographics Survey and Party ID survey
// Both these have no randomizations (and are only two CSVs), so this processing is more straightforward.

clear
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data\Demographics and PID surveys"

// DEMOGRAPHICS
insheet using  "Demographics_March_2016.csv", names

// drop empty qualtrics var that only exists in unicode
drop v56
drop if psid =="" // dropping test data

// this function takes the first row and makes it the var name, and then converts second row to be the label
foreach var of varlist * {
  label variable `var' "`=`var'[1]'"
  replace `var'="" if _n==1
  destring `var', replace
}

// drop first row, which is now empty
drop if v7 == .
rename v8 start_time // respondents started with the PID survey, so this is the accurate start time
label var start_time "When the respondent started the survey"

// save one folder up in the directory so that it can be merged with survey data
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"
save Demographics.dta, replace 

// PARTY ID
// Party ID was in a different survey because it also re-directed people to a candidate with the same Party ID
clear
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data\Demographics and PID surveys"
insheet using "a_Redirect_Survey_by_Party_ID_March_2016.csv", names

// drop empty qualtrics var
drop v24
drop if psid =="" // dropping test data

foreach var of varlist * {
  label variable `var' "`=`var'[1]'"
  replace `var'="" if _n==1
  destring `var', replace
}

// drop first row, which is now empty
drop if v7 == .
rename v9 end_time // respondents last saw the Demographics survey, so this is the accurate end time
label var end_time "When the respondent completed the survey"

rename q4 consent // The yes/no consent before the experiment began
label var consent "Consent to Participate in the experiment"
label define consent 1 "I agree to participate" 2 "I do not agree to participate"
label values consent consent 
tab consent // 42 did not consent. They "completed" the survey after the consent question and never saw any more (check: q2 is Party ID and it is empty).

// save one folder up in the directory so that it can be merged with survey data
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"
save PartyID.dta, replace 

/////////// MERGE DEMOS AND PARTY ID //////////////////
use Demographics, clear
sort psid
save Demographics.dta, replace

use PartyID, clear
sort psid
merge psid using Demographics
save PID_and_Demos.dta, replace


//////////////////////////////////////////////////////////////
// PART 8: 
// DROP DATA THAT DOESN'T EXIST: EMPTY QUALTRICS VARIABLES //
//////////////////////////////////////////////////////////////

// This drops test data, break off, cell phone users, and non-consenters

sort psid
sort q8 // q8 == 1 means they were auto booted bc. of cell phone
// program identified cell phone users:
drop if q8 == 1

// self-identified cell phone users:
sort q9 // q9 == 2 means they self identified cell phone users
drop if q9 == 2
sort _merge

// drop empty rows of those that did not consent
drop if consent == 2
drop if consent == .

// remaining _merge = 1 are break off; consented but didnt make it through entire survey (most quit before getting to Demos)
sort _merge
drop if _merge == 1
tab _merge 

sort v9 // launched on 4/19/16 at 2:31pm -> all completes should be AFTER this time (they are)

drop _merge
// FINAL DATASET TO BE MERGED WITH MAIN AND OPPOSITE
save PID_and_Demos.dta, replace

 

//////////////////////////////////////////////////////////
// PART 9: 
//MERGE CANDIDATE VIGNETTE, DEMOGRAPHICS, AND PARTY ID //
//////////////////////////////////////////////////////////

clear
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Mass Raw Survey Data"

use main_module_all_groups, clear
sort psid
save main_module_all_groups2, replace

use PID_and_Demos, clear
rename q7947 q7949edu // same variable name in both dataset. This keeps the education in the Demos dataset from dropping
sort psid
save PID_and_Demos2, replace

use main_module_all_groups2, clear
merge psid using PID_and_Demos2


tab _merge
sort _merge // From digging, 53 respondents broke off, never completed survey
drop if _merge == 1
drop _merge
compress 
save dataset_all_merged_not_recoded.dta, replace


/////////////////////////////////////////////////
// PART 10:
// RECODE Party ID and Some Demos
/////////////////////////////////////////////////

// Basic recoding below. More recoding occurs after merging Mass and Donor so that variable names are the same

// PARTY ID:
// The PID was programmed to force a response; meaning, no one should have been able to skip but this one person got through
// This person's psid is eLszeeGuhcAIT5YMKolUKA** 
// We don't know how this happened and consider it an error in fielding.
// eLszeeGuhcAIT5YMKolUKA** completed both the main module and the opposite module twice, before being redirected to the demographics survey (which they completed)
// Because we have no PID, and the person mistakenly took the survey twice, they will be dropped from the dataset:
list psid if q2 == . // one person get through PID question without answering
tab pid_candidate if psid =="eLszeeGuhcAIT5YMKolUKA**" // saw two main modules
drop if psid == "eLszeeGuhcAIT5YMKolUKA**"

// party id: 3 & 7 point, Independent leaners coded as partisans
// PID3
tab q2
gen pid3 = .
replace pid3 = -1 if q2 == 1
replace pid3 = 1 if q2 == 3
replace pid3 = 0 if q3 == 2
replace pid3 = -1 if q3 == 1
replace pid3 = 1 if q3 == 3
label var pid3 "3-point Party Identification"
label define pid3 -1 "Democrats" 0 "Independents" 1 "Republicans" 
label values pid3 pid3 
tab q2 pid3
tab pid3

// PID7
tab q2
gen pid7 = .
replace pid7 = -3 if q5 == 1
replace pid7 = -2 if q5 == 2
replace pid7 = -1 if q3 == 1
replace pid7 = 0 if q3 == 2
replace pid7 = 1 if q3 == 3
replace pid7 = 2 if q6 == . & q2 == 3 // two people skipped the GOP strength Q
replace pid7 = 2 if q6 == 2
replace pid7 = 3 if q6 == 1
label var pid7 "7-point Party Identification"
label define pid7 -3 "Strong Democrats" -2 "Weak Democrats" -1 "Leaning Democrats" 0 "Pure Independents" 1 "Leaning Republicans" 2 "Weak Republicans" 3 "Strong Republicans" 
label values pid7 pid7 
tab pid7
tab q2 pid7
tab q2

// EDUCATION LEVEL
tab q7949edu
gen education = q7949edu
label var education "What is your highest level of education you have completed?"
label define education  1 "Did not graduate from high school" 2 "High school graduate" 3 "Some college but no degree" 4 "2-year college degree" 5 "4-year college degree" 6 "Post graduate" 7 "Prefer not to say"
label values education education 
tab education

// RACE AND ETHNICITY
tab q25
gen race = q25
label var race "What racial or ethnic group best describes you?"
label define race  1 "White" 2 "Black or African American" 3 "Hispanic or Latino" 4 "Asian or Asian-American" 5 "Native American" 6 "Middle Eastern" 7 "Mixed race" 8 "Other" 9 "Prefer not to say"
label values race race 
tab race

// AGE
tab q26
gen age = 2016 - q26
label var age "Age (calculated from asking year of birth)"
tab age

// GENDER
tab q27
gen gender = q27
label var gender "Are you male or female?"
label define gender  1 "Male" 2 "Female" 3 "Other"
label values gender gender 
tab gender

// RACE AND GENDER RECODES FOR BALANCE ASSESSEMENTS
gen black = 0
replace black = 1 if race == 2

gen white = 0
replace white = 1 if race == 1

gen hispanic = 0
replace hispanic = 1 if race == 3

gen female = 0
replace female = 1 if gender == 2


// INCOME
tab q28
gen income = q28
label var income "Thinking back over the last year, what was your family's annual income?"
label define income  1 "Less than $10k" 2 "$10k - $14,999" 3 "$15k - $19,999" 4 "$20k - $24,999" 5 "$25k - $29,999" 6 "$30k - $39,999" 7 "$40k - $49,999" 8 "$50k - $59,999" 9 "$60k - $69,999" ///
10 "$70k - $79,999" 11 "$80k - $99,999" 12 "$100k - $119,999" 13 "$120k - $149,999" 14 "$150k - $199,999" 15 "$200k - $249,999" 16 "$250k or more" 17 "Prefer not to say"
label values income income 
tab income

// UNIQUE RESPONDENT ID AUTOMATICALLY GENERATED BY SSI
label var psid "Unique Respondent ID generated by Survey Sampling International (SSI)"

// LABELS FOR GROUP AND TREATMENT IDENTIFIERS
label var pid_candidate "Main Module: Party ID of Candidate in Vignette"
label var group "Main Module: Randomized Group Assignment as a String Variable"

// RANDOMIZED GROUP ASSIGNMENT VARIABLE AS A NUMBERIC INSTEAD OF A STRING
gen group_numeric = .
replace group_numeric = 1 if group =="group_1"
replace group_numeric = 2 if group =="group_2"
replace group_numeric = 3 if group =="group_3"
replace group_numeric = 4 if group =="group_4"
label define group_numeric  1 "Group 1: Aligned" 2 "Group 2: Extreme" 3 "Group 3: Unusual" 4 "Group 4: Bi-Partisan"
label values group_numeric group_numeric 
label var group_numeric "Main Module: Randomized Group Assignment as a Numeric Variable"
tab group_numeric

//unique ID
gen x = uniform()
sort x
gen ID = int(x*100000000)
label var ID "Respondent ID"
sort ID
quietly by ID:  gen dup = cond(_N==1,0,_n)
tab dup // All IDs are unique if dup==0
order ID, first




/////////////////////////////////////////////////
// PART 11:
// DROP OLD VARIABLES THAT ARE NO LONGER USEFUL
/////////////////////////////////////////////////
// Since our outcome measures were a combination of many questions across many surveys, each indivdiual question is not useful after combining
// This section drops all variables that are incomplete and cannot be used for analysis.
// Also drops qualitrics embedded data variables that were used for the survey flow
 
 drop V1 v2 v3 v4 v5 v6 v7 v8 v9 v10 ed q87 q1113_16 q1115_16 q1116 q1117 q1118_2 q1118_3 q1118_4 q1118_5 q1118_6 q1123 q1124 q1127 q1128 q1129 q1130 q1135 q1136 q1137 q1138 ///
 q1143_17 q1145_1 q1145_2 q1145_3 q1145_4 q1145_5 q1145_6 q1145_7 q1147_17 q1148_1 q1149_1 q1153_17 q1154_1 q1155_1 q1156_1 q1161_16 q1163_16 q1164 q1165 q1166_2 q1166_3 q1166_4 ///
 q1166_5 q1166_6 q1171 q1172 q1175 q1176 q1177 q1178 q1183 q1184 q1185 q1186 q1191_17 q1193_1 q1193_2 q1193_3 q1193_4 q1193_5 q1193_6 q1193_7 q1195_17 q1196_1 q1197_1 q1201_17 ///
 q1202_1 q1203_1 q1204_1 q1209_16 q1211_16 q1212 q1213 q1214_2 q1214_3 q1214_4 q1214_5 q1214_6 q1219 q1220 q1223 q1224 q1225 q1226 q1231 q1232 q1233 q1234 q1239_17 q1241_1 ///
 q1241_2 q1241_3 q1241_4 q1241_5 q1241_6 q1241_7 q1243_17 q1244_1 q1245_1 q1249_17 q1250_1 q1251_1 q1252_1 q1593_16 q1595_16 q1596 q1597 q1598_2 q1598_3 q1598_4 q1598_5 ///
 q1598_6 q1603 q1604 q1607 q1608 q1609 q1610 q1615 q1616 q1617 q1618 q1623_17 q1625_1 q1625_2 q1625_3 q1625_4 q1625_5 q1625_6 q1625_7 q1627_17 q1628_1 q1629_1 q1633_17 ///
 q1634_1 q1635_1 q1636_1 q1641_16 q1643_16 q1644 q1645 q1646_2 q1646_3 q1646_4 q1646_5 q1646_6 q1651 q1652 q1655 q1656 q1657 q1658 q1663 q1664 q1665 q1666 q1671_17 q1673_1 ///
 q1673_2 q1673_3 q1673_4 q1673_5 q1673_6 q1673_7 q1675_17 q1676_1 q1677_1 q1681_17 q1682_1 q1683_1 q1684_1 q1689_16 q1691_16 q1692 q1693 q1694_2 q1694_3 q1694_4 q1694_5 ///
 q1694_6 q1699 q1700 q1703 q1704 q1705 q1706 q1711 q1712 q1713 q1714 q1719_17 q1721_1 q1721_2 q1721_3 q1721_4 q1721_5 q1721_6 q1721_7 q1723_17 q1724_1 q1725_1 q1729_17 ///
 q1730_1 q1731_1 q1732_1 q1881_16 q1883_16 q1884 q1885 q1886_2 q1886_3 q1886_4 q1886_5 q1886_6 q1891 q1892 q1895 q1896 q1897 q1898 q1903 q1904 q1905 q1906 q1911_17 ///
 q1913_1 q1913_2 q1913_3 q1913_4 q1913_5 q1913_6 q1913_7 q1915_17 q1916_1 q1917_1 q1921_17 q1922_1 q1923_1 q1924_1 q1929_16 q1931_16 q1932 q1933 q1934_2 q1934_3 q1934_4 ///
 q1934_5 q1934_6 q1939 q1940 q1943 q1944 q1945 q1946 q1951 q1952 q1953 q1954 q1959_17 q1961_1 q1961_2 q1961_3 q1961_4 q1961_5 q1961_6 q1961_7 q1963_17 q1964_1 q1965_1 ///
 q1969_17 q1970_1 q1971_1 q1972_1 q1977_16 q1979_16 q1980 q1981 q2343_2 q2343_3 q2343_4 q2343_5 q2343_6 q1987 q1988 q1991 q1992 q1993 q1994 q1999 q2000 q2001 q2002 ///
 q2007_17 q2009_1 q2009_2 q2009_3 q2009_4 q2009_5 q2009_6 q2009_7 q2011_17 q2012_1 q2013_1 q2017_17 q2018_1 q2019_1 q2020_1 q2169_16 q2171_16 q2172 q2173 q2174_2 q2174_3 ///
 q2174_4 q2174_5 q2174_6 q2179 q2180 q2183 q2184 q2185 q2186 q2191 q2192 q2193 q2194 q2199_17 q2201_1 q2201_2 q2201_3 q2201_4 q2201_5 q2201_6 q2201_7 q2203_17 q2204_1 ///
 q2205_1 q2209_17 q2210_1 q2211_1 q2212_1 q2217_16 q2219_16 q2220 q2221 q2222_2 q2222_3 q2222_4 q2222_5 q2222_6 q2227 q2228 q2231 q2232 q2233 q2234 q2239 q2240 q2241 ///
 q2242 q2247_17 q2249_1 q2249_2 q2249_3 q2249_4 q2249_5 q2249_6 q2249_7 q2251_17 q2252_1 q2253_1 q2257_17 q2258_1 q2259_1 q2260_1 q2265_16 q2267_16 q2268 q2269 q2270_2 ///
 q2270_3 q2270_4 q2270_5 q2270_6 q2275 q2276 q2279 q2280 q2281 q2282 q2287 q2288 q2289 q2290 q2295_17 q2297_1 q2297_2 q2297_3 q2297_4 q2297_5 q2297_6 q2297_7 q2299_17 ///
 q2300_1 q2301_1 q2305_17 q2306_1 q2307_1 q2308_1 q2457_16 q2459_16 q2460 q2461 q2462_2 q2462_3 q2462_4 q2462_5 q2462_6 q2467 q2468 q2471 q2472 q2473 q2474 q2479 q2480 ///
 q2481 q2482 q2487_17 q2489_1 q2489_2 q2489_3 q2489_4 q2489_5 q2489_6 q2489_7 q2491_17 q2492_1 q2493_1 q2497_17 q2498_1 q2499_1 q2500_1 q2505_16 q2507_16 q2508 q2509 ///
 q2510_2 q2510_3 q2510_4 q2510_5 q2510_6 q2515 q2516 q2519 q2520 q2521 q2522 q2527 q2528 q2529 q2530 q2535_17 q2537_1 q2537_2 q2537_3 q2537_4 q2537_5 q2537_6 q2537_7 ///
 q2539_17 q2540_1 q2541_1 q2545_17 q2546_1 q2547_1 q2548_1 q2553_16 q2555_16 q2556 q2557 q2558_2 q2558_3 q2558_4 q2558_5 q2558_6 q2563 q2564 q2567 q2568 q2569 q2570 ///
 q2575 q2576 q2577 q2578 q2583_17 q2585_1 q2585_2 q2585_3 q2585_4 q2585_5 q2585_6 q2585_7 q2587_17 q2588_1 q2589_1 q2593_17 q2594_1 q2595_1 q2596_1 q2745_16 q2747_16 ///
 q2748 q2749 q2750_2 q2750_3 q2750_4 q2750_5 q2750_6 q2755 q2756 q2759 q2760 q2761 q2762 q2767 q2768 q2769 q2770 q2775_17 q2777_1 q2777_2 q2777_3 q2777_4 q2777_5 ///
 q2777_6 q2777_7 q2779_17 q2780_1 q2781_1 q2785_17 q2786_1 q2787_1 q2788_1 q2793_16 q2795_16 q2796 q2797 q2798_2 q2798_3 q2798_4 q2798_5 q2798_6 q2803 q2804 q2807 ///
 q2808 q2809 q2810 q2815 q2816 q2817 q2818 q2823_17 q2825_1 q2825_2 q2825_3 q2825_4 q2825_5 q2825_6 q2825_7 q2827_17 q2828_1 q2829_1 q2833_17 q2834_1 q2835_1 q2836_1 ///
 q2841_16 q2843_16 q2844 q2845 q2846_2 q2846_3 q2846_4 q2846_5 q2846_6 q2851 q2852 q2855 q2856 q2857 q2858 q2863 q2864 q2865 q2866 q2871_17 q2873_1 q2873_2 q2873_3 ///
 q2873_4 q2873_5 q2873_6 q2873_7 q2875_17 q2876_1 q2877_1 q2881_17 q2882_1 q2883_1 q2884_1 q3033_16 q3035_16 q3036 q3037 q3038_2 q3038_3 q3038_4 q3038_5 q3038_6 q3043 ///
 q3044 q3047 q3048 q3049 q3050 q3055 q3056 q3057 q3058 q3063_17 q3065_1 q3065_2 q3065_3 q3065_4 q3065_5 q3065_6 q3065_7 q3067_17 q3068_1 q3069_1 q3073_17 q3074_1 ///
 q3075_1 q3076_1 q3081_16 q3083_16 q3084 q3085 q3086_2 q3086_3 q3086_4 q3086_5 q3086_6 q3091 q3092 q3095 q3096 q3097 q3098 q3103 q3104 q3105 q3106 q3111_17 q3113_1 ///
 q3113_2 q3113_3 q3113_4 q3113_5 q3113_6 q3113_7 q3115_17 q3116_1 q3117_1 q3121_17 q3122_1 q3123_1 q3124_1 q3129_16 q3131_16 q3132 q3133 q3134_2 q3134_3 q3134_4 q3134_5 ///
 q3134_6 q3139 q3140 q3143 q3144 q3145 q3146 q3151 q3152 q3153 q3154 q3159_17 q3161_1 q3161_2 q3161_3 q3161_4 q3161_5 q3161_6 q3161_7 q3163_17 q3164_1 q3165_1 q3169_17 ///
 q3170_1 q3171_1 q3172_1 q3177_16 q3179_16 q3180 q3181 q3182_2 q3182_3 q3182_4 q3182_5 q3182_6 q3187 q3188 q3191 q3192 q3193 q3194 q3199 q3200 q3201 q3202 q3207_17 ///
 q3209_1 q3209_2 q3209_3 q3209_4 q3209_5 q3209_6 q3209_7 q3211_17 q3212_1 q3213_1 q3217_17 q3218_1 q3219_1 q3220_1 q3225_16 q3227_16 q3228 q3229 q3230_2 q3230_3 ///
 q3230_4 q3230_5 q3230_6 q3235 q3236 q3239 q3240 q3241 q3242 q3247 q3248 q3249 q3250 q3255_17 q3257_1 q3257_2 q3257_3 q3257_4 q3257_5 q3257_6 q3257_7 q3259_17 ///
 q3260_1 q3261_1 q3265_17 q3266_1 q3267_1 q3268_1 q3273_16 q3275_16 q3276 q3277 q3278_2 q3278_3 q3278_4 q3278_5 q3278_6 q3283 q3284 q3287 q3288 q3289 q3290 q3295 ///
 q3296 q3297 q3298 q3303_17 q3305_1 q3305_2 q3305_3 q3305_4 q3305_5 q3305_6 q3305_7 q3307_17 q3308_1 q3309_1 q3313_17 q3314_1 q3315_1 q3316_1 q3465_16 q3467_16 ///
 q3468 q3469 q3470_2 q3470_3 q3470_4 q3470_5 q3470_6 q3475 q3476 q3479 q3480 q3481 q3482 q3487 q3488 q3489 q3490 q3495_17 q3497_1 q3497_2 q3497_3 q3497_4 q3497_5 ///
 q3497_6 q3497_7 q3499_17 q3500_1 q3501_1 q3505_17 q3506_1 q3507_1 q3508_1 q3513_16 q3515_16 q3516 q3517 q3518_2 q3518_3 q3518_4 q3518_5 q3518_6 q3523 q3524 q3527 ///
 q3528 q3529 q3530 q3535 q3536 q3537 q3538 q3543_17 q3545_1 q3545_2 q3545_3 q3545_4 q3545_5 q3545_6 q3545_7 q3547_17 q3548_1 q3549_1 q3553_17 q3554_1 q3555_1 q3556_1 ///
 q3609_16 q3611_16 q3612 q3613 q3614_2 q3614_3 q3614_4 q3614_5 q3614_6 q3619 q3620 q3623 q3624 q3625 q3626 q3631 q3632 q3633 q3634 q3639_17 q3641_1 q3641_2 q3641_3 ///
 q3641_4 q3641_5 q3641_6 q3641_7 q3643_17 q3644_1 q3645_1 q3649_17 q3650_1 q3651_1 q3652_1 q3657_16 q3659_16 q3660 q3661 q3662_2 q3662_3 q3662_4 q3662_5 q3662_6 ///
 q3667 q3668 q3671 q3672 q3673 q3674 q3679 q3680 q3681 q3682 q3687_17 q3689_1 q3689_2 q3689_3 q3689_4 q3689_5 q3689_6 q3689_7 q3691_17 q3692_1 q3693_1 q3697_17 ///
 q3698_1 q3699_1 q3700_1 q3705_16 q3707_16 q3708 q3709 q3710_2 q3710_3 q3710_4 q3710_5 q3710_6 q3715 q3716 q3719 q3720 q3721 q3722 q3727 q3728 q3729 q3730 q3735_17 ///
 q3737_1 q3737_2 q3737_3 q3737_4 q3737_5 q3737_6 q3737_7 q3739_17 q3740_1 q3741_1 q3745_17 q3746_1 q3747_1 q3748_1 q3753_16 q3755_16 q3756 q3757 q3758_2 q3758_3 ///
 q3758_4 q3758_5 q3758_6 q3763 q3764 q3767 q3768 q3769 q3770 q3775 q3776 q3777 q3778 q3783_17 q3785_1 q3785_2 q3785_3 q3785_4 q3785_5 q3785_6 q3785_7 q3787_17 ///
 q3788_1 q3789_1 q3793_17 q3794_1 q3795_1 q3796_1 locationlatitude locationlongitude locationaccuracy q1_16 q110_16 q45 q46 ///
 q47_2 q47_3 q47_4 q47_5 q47_6 q111 q49 q119 q51 q52 q53 q125 q55 q56 q57 q130_17 q132_1 q132_2 q132_3 q132_4 q132_5 q132_6 q132_7 q134_17 q42_1 q43_1 q138_17 ///
 q64_1 q61_1 q62_1 q825_16 q827_16 q828 q829 q830_2 q830_3 q830_4 q830_5 q830_6 q835 q836 q839 q840 q841 q842 q847 q848 q849 q850 q855_17 q857_1 q857_2 q857_3 ///
 q857_4 q857_5 q857_6 q857_7 q859_17 q860_1 q861_1 q865_17 q866_1 q867_1 q868_1 q873_16 q875_16 q876 q877 q878_2 q878_3 q878_4 q878_5 q878_6 q883 q884 q887 q888 ///
 q889 q890 q895 q896 q897 q898 q903_17 q905_1 q905_2 q905_3 q905_4 q905_5 q905_6 q905_7 q907_17 q908_1 q909_1 q913_17 q914_1 q915_1 q916_1 q921_16 q923_16 q924 ///
 q925 q926_2 q926_3 q926_4 q926_5 q926_6 q931 q932 q935 q936 q937 q938 q943 q944 q945 q946 q951_17 q953_1 q953_2 q953_3 q953_4 q953_5 q953_6 q953_7 q955_17 ///
 q956_1 q957_1 q961_17 q962_1 q963_1 q964_1 q969_16 q971_16 q972 q973 q974_2 q974_3 q974_4 q974_5 q974_6 q979 q980 q983 q984 q985 q986 q991 q992 q993 q994 ///
 q999_17 q1001_1 q1001_2 q1001_3 q1001_4 q1001_5 q1001_6 q1001_7 q1003_17 q1004_1 q1005_1 q1009_17 q1010_1 q1011_1 q1012_1 q1065_16 q1067_16 q1068 q1069 ///
 q1070_2 q1070_3 q1070_4 q1070_5 q1070_6 q1075 q1076 q1079 q1080 q1081 q1082 q1087 q1088 q1089 q1090 q1097_1 q1097_2 q1097_3 q1097_4 q1097_5 q1097_6 q1097_7 ///
 q1095_17 q1099_17 q1100_1 q1101_1 q1105_17 q1106_1 q1107_1 q1108_1 q1257_16 q1259_16 q1260 q1261 q1262_2 q1262_3 q1262_4 q1262_5 q1262_6 q1267 q1268 q1271 ///
 q1272 q1273 q1274 q1279 q1280 q1281 q1282 q1287_17 q1289_1 q1289_2 q1289_3 q1289_4 q1289_5 q1289_6 q1289_7 q1291_17 q1292_1 q1293_1 q1297_17 q1298_1 q1299_1 ///
 q1300_1 q1305_16 q1307_16 q1308 q1309 q1310_2 q1310_3 q1310_4 q1310_5 q1310_6 q1315 q1316 q1319 q1320 q1321 q1322 q1327 q1328 q1329 q1330 q1335_17 q1337_1 ///
 q1337_2 q1337_3 q1337_4 q1337_5 q1337_6 q1337_7 q1339_17 q1340_1 q1341_1 q1345_17 q1346_1 q1347_1 q1348_1 q1353_16 q1355_16 q1356 q1357 q1358_2 q1358_3 ///
 q1358_4 q1358_5 q1358_6 q1363 q1364 q1367 q1368 q1369 q1370 q1375 q1376 q1377 q1378 q1383_17 q1385_1 q1385_2 q1385_3 q1385_4 q1385_5 q1385_6 q1385_7 ///
 q1387_17 q1388_1 q1389_1 q1393_17 q1394_1 q1395_1 q1396_1 q1401_16 q1403_16 q1404 q1405 q1406_2 q1406_3 q1406_4 q1406_5 q1406_6 q1411 q1412 q1415 q1416 ///
 q1417 q1418 q1423 q1424 q1425 q1426 q1431_17 q1433_1 q1433_2 q1433_3 q1433_4 q1433_5 q1433_6 q1433_7 q1435_17 q1436_1 q1437_1 q1441_17 q1442_1 q1443_1 ///
 q1444_1 q1449_16 q1451_16 q1452 q1453 q1454_2 q1454_3 q1454_4 q1454_5 q1454_6 q1459 q1460 q1463 q1464 q1465 q1466 q1471 q1472 q1473 q1474 q1479_17 q1481_1 ///
 q1481_2 q1481_3 q1481_4 q1481_5 q1481_6 q1481_7 q1483_17 q1484_1 q1485_1 q1489_17 q1490_1 q1491_1 q1492_1 q1497_16 q1499_16 q1500 q1501 q1502_2 q1502_3 ///
 q1502_4 q1502_5 q1502_6 q1507 q1508 q1511 q1512 q1513 q1514 q1519 q1520 q1521 q1522 q1527_17 q1529_1 q1529_2 q1529_3 q1529_4 q1529_5 q1529_6 q1529_7 ///
 q1531_17 q1532_1 q1533_1 q1537_17 q1538_1 q1539_1 q1540_1 q1737_16 q1739_16 q1740 q1741 q1742_2 q1742_3 q1742_4 q1742_5 q1742_6 q1747 q1748 q1751 q1752 ///
 q1753 q1754 q1759 q1760 q1761 q1762 q1767_17 q1769_1 q1769_2 q1769_3 q1769_4 q1769_5 q1769_6 q1769_7 q1771_17 q1772_1 q1773_1 q1777_17 q1778_1 q1779_1 ///
 q1780_1 q1785_16 q1787_16 q1788 q1789 q1790_2 q1790_3 q1790_4 q1790_5 q1790_6 q1795 q1796 q1799 q1800 q1801 q1802 q1807 q1808 q1809 q1810 q1815_17 q1817_1 ///
 q1817_2 q1817_3 q1817_4 q1817_5 q1817_6 q1817_7 q1819_17 q1820_1 q1821_1 q1825_17 q1826_1 q1827_1 q1828_1 q1833_16 q1835_16 q1836 q1837 q1838_2 q1838_3 ///
 q1838_4 q1838_5 q1838_6 q1843 q1844 q1847 q1848 q1849 q1850 q1855 q1856 q1857 q1858 q1863_17 q1865_1 q1865_2 q1865_3 q1865_4 q1865_5 q1865_6 q1865_7 ///
 q1867_17 q1868_1 q1869_1 q1873_17 q1874_1 q1875_1 q1876_1 q2025_16 q2027_16 q2028 q2029 q2030_2 q2030_3 q2030_4 q2030_5 q2030_6 q2035 q2036 q2039 ///
 q2040 q2041 q2042 q2047 q2048 q2049 q2050 q2055_17 q2057_1 q2057_2 q2057_3 q2057_4 q2057_5 q2057_6 q2057_7 q2059_17 q2060_1 q2061_1 q2065_17 q2066_1 ///
 q2067_1 q2068_1 q2073_16 q2075_16 q2076 q2077 q2078_2 q2078_3 q2078_4 q2078_5 q2078_6 q2083 q2084 q2087 q2088 q2089 q2090 q2095 q2096 q2097 q2098 ///
 q2103_17 q2105_1 q2105_2 q2105_3 q2105_4 q2105_5 q2105_6 q2105_7 q2107_17 q2108_1 q2109_1 q2113_17 q2114_1 q2115_1 q2116_1 q2121_16 q2123_16 q2124 ///
 q2125 q2126_2 q2126_3 q2126_4 q2126_5 q2126_6 q2131 q2132 q2135 q2136 q2137 q2138 q2143 q2144 q2145 q2146 q2151_17 q2153_1 q2153_2 q2153_3 q2153_4 ///
 q2153_5 q2153_6 q2153_7 q2155_17 q2156_1 q2157_1 q2161_17 q2162_1 q2163_1 q2164_1 q2313_16 q2315_16 q2316 q2317 q2318_2 q2318_3 q2318_4 q2318_5 q2318_6 ///
 q2323 q2324 q2327 q2328 q2329 q2330 q2335 q2336 q2337 q2338 q2343_17 q2345_1 q2345_2 q2345_3 q2345_4 q2345_5 q2345_6 q2345_7 q2347_17 q2348_1 q2349_1 ///
 q2353_17 q2354_1 q2355_1 q2356_1 q2361_16 q2363_16 q2364 q2365 q2366_2 q2366_3 q2366_4 q2366_5 q2366_6 q2371 q2372 q2375 q2376 q2377 q2378 q2383 q2384 q2385 ///
 q2386 q2391_17 q2393_1 q2393_2 q2393_3 q2393_4 q2393_5 q2393_6 q2393_7 q2395_17 q2396_1 q3504_1 q2397_1 q2401_17 q2402_1 q2403_1 q2404_1 q2409_16 q2411_16 q2412 q2413 ///
 q2414_2 q2414_3 q2414_4 q2414_5 q2414_6 q2419 q2420 q2423 q2424 q2425 q2426 q2431 q2432 q2433 q2434 q2439_17 q2441_1 q2441_2 q2441_3 q2441_4 q2441_5 q2441_6 ///
 q2441_7 q2443_17 q2444_1 q2445_1 q2449_17 q2450_1 q2451_1 q2452_1 q2601_16 q2603_16 q2604 q2605 q2606_2 q2606_3 q2606_4 q2606_5 q2606_6 q2611 q2612 q2615 ///
 q2616 q2617 q2618 q2623 q2624 q2625 q2626 q2631_17 q2633_1 q2633_2 q2633_3 q2633_4 q2633_5 q2633_6 q2633_7 q2635_17 q2636_1 q2637_1 q2641_17 q2642_1 q2643_1 ///
 q2644_1 q2649_16 q2651_16 q2652 q2653 q2654_2 q2654_3 q2654_4 q2654_5 q2654_6 q2659 q2660 q2663 q2664 q2665 q2666 q2671 q2672 q2673 q2674 q2679_17 q2681_1 ///
 q2681_2 q2681_3 q2681_4 q2681_5 q2681_6 q2681_7 q2683_17 q2684_1 q2685_1 q2689_17 q2690_1 q2691_1 q2692_1 q2697_16 q2699_16 q2700 q2701 q2702_2 q2702_3 ///
 q2702_4 q2702_5 q2702_6 q2707 q2708 q2711 q2712 q2713 q2714 q2719 q2720 q2721 q2722 q2727_17 q2729_1 q2729_2 q2729_3 q2729_4 q2729_5 q2729_6 q2729_7 ///
 q2731_17 q2732_1 q2733_1 q2737_17 q2738_1 q2739_1 q2740_1 q3321_16 q3323_16 q3324 q3325 q3326_2 q3326_3 q3326_4 q3326_5 q3326_6 q3331 q3332 q3335 q3336 ///
 q3337 q3338 q3343 q3344 q3345 q3346 q3351_17 q3353_1 q3353_2 q3353_3 q3353_4 q3353_5 q3353_6 q3353_7 q3355_17 q3356_1 q3357_1 q3361_17 q3362_1 q3363_1 ///
 q3364_1 q3369_16 q3371_16 q3372 q3373 q3374_2 q3374_3 q3374_4 q3374_5 q3374_6 q3379 q3380 q3383 q3384 q3385 q3386 q3391 q3392 q3393 q3394 q3399_17 q3401_1 ///
 q3401_2 q3401_3 q3401_4 q3401_5 q3401_6 q3401_7 q3403_17 q3404_1 q3405_1 q3409_17 q3410_1 q3411_1 q3412_1 q3417_16 q3419_16 q3420 q3421 q3422_2 q3422_3 ///
 q3422_4 q3422_5 q3422_6 q3427 q3428 q3431 q3432 q3433 q3434 q3439 q3440 q3441 q3442 q3447_17 q3449_1 q3449_2 q3449_3 q3449_4 q3449_5 q3449_6 q3449_7 ///
 q3451_17 q3452_1 q3453_1 q3457_17 q3458_1 q3459_1 q3460_1 q2889_16 q2891_16 q2892 q2893 q2894_2 q2894_3 q2894_4 q2894_5 q2894_6 q2899 q2900 q2903 q2904 ///
 q2905 q2906 q2911 q2912 q2913 q2914 q2919_17 q2921_1 q2921_2 q2921_3 q2921_4 q2921_5 q2921_6 q2921_7 q2923_17 q2924_1 q2925_1 q2929_17 q2930_1 q2931_1 ///
 q2932_1 q2937_16 q2939_16 q2940 q2941 q2942_2 q2942_3 q2942_4 q2942_5 q2942_6 q2947 q2948 q2951 q2952 q2953 q2954 q2959 q2960 q2961 q2962 q2967_17 q2969_1 ///
 q2969_2 q2969_3 q2969_4 q2969_5 q2969_6 q2969_7 q2971_17 q2972_1 q2973_1 q2977_17 q2978_1 q2979_1 q2980_1 q2985_16 q2987_16 q2988 q2989 q2990_2 q2990_3 ///
 q2990_4 q2990_5 q2990_6 q2995 q2996 q2999 q3000 q3001 q3002 q3007 q3008 q3009 q3010 q3015_17 q3017_1 q3017_2 q3017_3 q3017_4 q3017_5 q3017_6 q3017_7 ///
 q3019_17 q3020_1 q3021_1 q3025_17 q3026_1 q3027_1 q3028_1 q1114_16 q1119_16 q1120 q1121 q1122_2 q1122_3 q1122_4 q1122_5 q1122_6 q1125 q1126 q1131 q1132 ///
 q1133 q1134 q1139 q1140 q1141 q1142 q1144_17 q1146_1 q1146_2 q1146_3 q1146_4 q1146_5 q1146_6 q1146_7 q1150_17 q1151_1 q1152_1 q1157_17 q1158_1 q1159_1 ///
 q1160_1 q1162_16 q1167_16 q1168 q1169 q1170_2 q1170_3 q1170_4 q1170_5 q1170_6 q1173 q1174 q1179 q1180 q1181 q1182 q1187 q1188 q1189 q1190 q1192_17 q1194_1 ///
 q1194_2 q1194_3 q1194_4 q1194_5 q1194_6 q1194_7 q1198_17 q1199_1 q1200_1 q1205_17 q1206_1 q1207_1 q1208_1 q1210_16 q1215_16 q1216 q1217 q1218_2 q1218_3 ///
 q1218_4 q1218_5 q1218_6 q1221 q1222 q1227 q1228 q1229 q1230 q1235 q1236 q1237 q1238 q1240_17 q1242_1 q1242_2 q1242_3 q1242_4 q1242_5 q1242_6 q1242_7 q1246_17 ///
 q1247_1 q1248_1 q1253_17 q1254_1 q1255_1 q1256_1 q1594_16 q1599_16 q1600 q1601 q1602_2 q1602_3 q1602_4 q1602_5 q1602_6 q1605 q1606 q1611 q1612 q1613 q1614 ///
 q1619 q1620 q1621 q1622 q1624_17 q1626_1 q1626_2 q1626_3 q1626_4 q1626_5 q1626_6 q1626_7 q1630_17 q1631_1 q1632_1 q1637_17 q1638_1 q1639_1 q1640_1 q1642_16 ///
 q1647_16 q1648 q1649 q1650_2 q1650_3 q1650_4 q1650_5 q1650_6 q1653 q1654 q1659 q1660 q1661 q1662 q1667 q1668 q1669 q1670 q1672_17 q1674_1 q1674_2 q1674_3 ///
 q1674_4 q1674_5 q1674_6 q1674_7 q1678_17 q1679_1 q1680_1 q1685_17 q1686_1 q1687_1 q1688_1 q1690_16 q1695_16 q1696 q1697 q1698_2 q1698_3 q1698_4 q1698_5 ///
 q1698_6 q1701 q1702 q1707 q1708 q1709 q1710 q1715 q1716 q1717 q1718 q1720_17 q1722_1 q1722_2 q1722_3 q1722_4 q1722_5 q1722_6 q1722_7 q1726_17 q1727_1 ///
 q1728_1 q1733_17 q1734_1 q1735_1 q1736_1 q1882_16 q1887_16 q1888 q1889 q1890_2 q1890_3 q1890_4 q1890_5 q1890_6 q1893 q1894 q1899 q1900 q1901 q1902 q1907 ///
 q1908 q1909 q1910 q1912_17 q1914_1 q1914_2 q1914_3 q1914_4 q1914_5 q1914_6 q1914_7 q1918_17 q1919_1 q1920_1 q1925_17 q1926_1 q1927_1 q1928_1 q1930_16 ///
 q1935_16 q1936 q1937 q1938_2 q1938_3 q1938_4 q1938_5 q1938_6 q1941 q1942 q1947 q1948 q1949 q1950 q1955 q1956 q1957 q1958 q1960_17 q1962_1 q1962_2 q1962_3 ///
 q1962_4 q1962_5 q1962_6 q1962_7 q1966_17 q1967_1 q1968_1 q1973_17 q1974_1 q1975_1 q1976_1 q1978_16 q1983_16 q1984 q1985 q1986_2 q1986_3 q1986_4 q1986_5 ///
 q1986_6 q1989 q1990 q1995 q1996 q1997 q1998 q2003 q2004 q2005 q2006 q2008_17 q2010_1 q2010_2 q2010_3 q2010_4 q2010_5 q2010_6 q2010_7 q2014_17 q2015_1 ///
 q2016_1 q2021_17 q2022_1 q2023_1 q2024_1 q2170_16 q2175_16 q2176 q2177 q2178_2 q2178_3 q2178_4 q2178_5 q2178_6 q2181 q2182 q2187 q2188 q2189 q2190 ///
 q2195 q2196 q2197 q2198 q2200_17 q2202_1 q2202_2 q2202_3 q2202_4 q2202_5 q2202_6 q2202_7 q2206_17 q2207_1 q2208_1 q2213_17 q2214_1 q2215_1 q2216_1 ///
 q2218_16 q2223_16 q2224 q2225 q2226_2 q2226_3 q2226_4 q2226_5 q2226_6 q2229 q2230 q2235 q2236 q2237 q2238 q2243 q2244 q2245 q2246 q2248_17 q2250_1 ///
 q2250_2 q2250_3 q2250_4 q2250_5 q2250_6 q2250_7 q2254_17 q2255_1 q2256_1 q2261_17 q2262_1 q2263_1 q2264_1 q2266_16 q2271_16 q2272 q2273 q2274_2 q2274_3 ///
 q2274_4 q2274_5 q2274_6 q2277 q2278 q2283 q2284 q2285 q2286 q2291 q2292 q2293 q2294 q2296_17 q2298_1 q2298_2 q2298_3 q2298_4 q2298_5 q2298_6 q2298_7 ///
 q2302_17 q2303_1 q2304_1 q2309_17 q2310_1 q2311_1 q2312_1 q2458_16 q2463_16 q2464 q2465 q2466_2 q2466_3 q2466_4 q2466_5 q2466_6 q2469 q2470 q2475 ///
 q2476 q2477 q2478 q2483 q2484 q2485 q2486 q2488_17 q2490_1 q2490_2 q2490_3 q2490_4 q2490_5 q2490_6 q2490_7 q2494_17 q2495_1 q2496_1 q2501_17 q2502_1 ///
 q2503_1 q2504_1 q2506_16 q2511_16 q2512 q2513 q2514_2 q2514_3 q2514_4 q2514_5 q2514_6 q2517 q2518 q2523 q2524 q2525 q2526 q2531 q2532 q2533 q2534 ///
 q2536_17 q2538_1 q2538_2 q2538_3 q2538_4 q2538_5 q2538_6 q2538_7 q2542_17 q2543_1 q2544_1 q2549_17 q2550_1 q2551_1 q2552_1 q2554_16 q2559_16 q2560 ///
 q2561 q2562_2 q2562_3 q2562_4 q2562_5 q2562_6 q2565 q2566 q2571 q2572 q2573 q2574 q2579 q2580 q2581 q2582 q2584_17 q2586_1 q2586_2 q2586_3 q2586_4 ///
 q2586_5 q2586_6 q2586_7 q2590_17 q2591_1 q2592_1 q2597_17 q2598_1 q2599_1 q2600_1 q2746_16 q2751_16 q2752 q2753 q2754_2 q2754_3 q2754_4 q2754_5 q2754_6 ///
 q2757 q2758 q2763 q2764 q2765 q2766 q2771 q2772 q2773 q2774 q2776_17 q2778_1 q2778_2 q2778_3 q2778_4 q2778_5 q2778_6 q2778_7 q2782_17 q2783_1 q2784_1 ///
 q2789_17 q2790_1 q2791_1 q2792_1 q2794_16 q2799_16 q2800 q2801 q2802_2 q2802_3 q2802_4 q2802_5 q2802_6 q2805 q2806 q2811 q2812 q2813 q2814 q2819 q2820 ///
 q2821 q2822 q2824_17 q2826_1 q2826_2 q2826_3 q2826_4 q2826_5 q2826_6 q2826_7 q2830_17 q2831_1 q2832_1 q2837_17 q2838_1 q2839_1 q2840_1 q2842_16 q2847_16 ///
 q2848 q2849 q2850_2 q2850_3 q2850_4 q2850_5 q2850_6 q2853 q2854 q2859 q2860 q2861 q2862 q2867 q2868 q2869 q2870 q2872_17 q2874_1 q2874_2 q2874_3 q2874_4 ///
 q2874_5 q2874_6 q2874_7 q2878_17 q2879_1 q2880_1 q2885_17 q2886_1 q2887_1 q2888_1 q3034_16 q3039_16 q3040 q3041 q3042_2 q3042_3 q3042_4 q3042_5 q3042_6 ///
 q3045 q3046 q3051 q3052 q3053 q3054 q3059 q3060 q3061 q3062 q3064_17 q3066_1 q3066_2 q3066_3 q3066_4 q3066_5 q3066_6 q3066_7 q3070_17 q3071_1 q3072_1 ///
 q3077_17 q3078_1 q3079_1 q3080_1 q3082_16 q3087_16 q3088 q3089 q3090_2 q3090_3 q3090_4 q3090_5 q3090_6 q3093 q3094 q3099 q3100 q3101 q3102 q3107 q3108 ///
 q3109 q3110 q3112_17 q3114_1 q3114_2 q3114_3 q3114_4 q3114_5 q3114_6 q3114_7 q3118_17 q3119_1 q3120_1 q3125_17 q3126_1 q3127_1 q3128_1 q3130_16 q3135_16 ///
 q3136 q3137 q3138_2 q3138_3 q3138_4 q3138_5 q3138_6 q3141 q3142 q3147 q3148 q3149 q3150 q3155 q3156 q3157 q3158 q3160_17 q3162_1 q3162_2 q3162_3 q3162_4 ///
 q3162_5 q3162_6 q3162_7 q3166_17 q3167_1 q3168_1 q3173_17 q3174_1 q3175_1 q3176_1 q7945_16 q7946_16 q7947 q7948 q7949_2 q7949_3 q7949_4 q7949_5 q7949_6 ///
 q7950 q7951 q7952 q7953 q7954 q7955 q7956 q7957 q7958 q7959 q7960_17 q7961_1 q7961_2 q7961_3 q7961_4 q7961_5 q7961_6 q7961_7 q7962_17 q7963_1 q7964_1 ///
 q7965_17 q7966_1 q7967_1 q7968_1 q3226_16 q3231_16 q3232 q3233 q3234_2 q3234_3 q3234_4 q3234_5 q3234_6 q3237 q3238 q3243 q3244 q3245 q3246 q3251 q3252 ///
 q3253 q3254 q3256_17 q3258_1 q3258_2 q3258_3 q3258_4 q3258_5 q3258_6 q3258_7 q3262_17 q3263_1 q3264_1 q3269_17 q3270_1 q3271_1 q3272_1 q3274_16 q3279_16 ///
 q3280 q3281 q3282_2 q3282_3 q3282_4 q3282_5 q3282_6 q3285 q3286 q3291 q3292 q3293 q3294 q3299 q3300 q3301 q3302 q3304_17 q3306_1 q3306_2 q3306_3 q3306_4 ///
 q3306_5 q3306_6 q3306_7 q3310_17 q3311_1 q3312_1 q3317_17 q3318_1 q3319_1 q3320_1 q3466_16 q3471_16 q3472 q3473 q3474_2 q3474_3 q3474_4 q3474_5 q3474_6 ///
 q3477 q3478 q3483 q3484 q3485 q3486 q3491 q3492 q3493 q3494 q3496_17 q3498_1 q3498_2 q3498_3 q3498_4 q3498_5 q3498_6 q3498_7 q3502_17 q3503_1 q3504_1 ///
 q3509_17 q3510_1 q3511_1 q3512_1 q7969_16 q7970_16 q7971 q7972 q7973_2 q7973_3 q7973_4 q7973_5 q7973_6 q7974 q7975 q7976 q7977 q7978 q7979 q7980 q7981 ///
 q7982 q7983 q7984_17 q7985_1 q7985_2 q7985_3 q7985_4 q7985_5 q7985_6 q7985_7 q7986_17 q7987_1 q7988_1 q7989_17 q7990_1 q7991_1 q7992_1 q3610_16 q3615_16 ///
 q3616 q3617 q3618_2 q3618_3 q3618_4 q3618_5 q3618_6 q3621 q3622 q3627 q3628 q3629 q3630 q3635 q3636 q3637 q3638 q3640_17 q3642_1 q3642_2 q3642_3 q3642_4 q3642_5 ///
 q3642_6 q3642_7 q3646_17 q3647_1 q3648_1 q3653_17 q3654_1 q3655_1 q3656_1 q3658_16 q3663_16 q3664 q3665 q3666_2 q3666_3 q3666_4 q3666_5 q3666_6 q3669 q3670 ///
 q3675 q3676 q3677 q3678 q3683 q3684 q3685 q3686 q3688_17 q3690_1 q3690_2 q3690_3 q3690_4 q3690_5 q3690_6 q3690_7 q3694_17 q3695_1 q3696_1 q3701_17 q3702_1 ///
 q3703_1 q3704_1 q3706_16 q3711_16 q3712 q3713 q3714_2 q3714_3 q3714_4 q3714_5 q3714_6 q3717 q3718 q3723 q3724 q3725 q3726 q3731 q3732 q3733 q3734 q3736_17 ///
 q3738_1 q3738_2 q3738_3 q3738_4 q3738_5 q3738_6 q3738_7 q3742_17 q3743_1 q3744_1 q3749_17 q3750_1 q3751_1 q3752_1 q3754_16 q3759_16 q3760 q3761 q3762_2 ///
 q3762_3 q3762_4 q3762_5 q3762_6 q3765 q3766 q3771 q3772 q3773 q3774 q3779 q3780 q3781 q3782 q3784_17 q3786_1 q3786_2 q3786_3 q3786_4 q3786_5 q3786_6 q3786_7 ///
 q3790_17 q3791_1 q3792_1 q3797_17 q3798_1 q3799_1 q3800_1 q102_16 q117_16 q112 q113 q114_2 q114_3 q114_4 q114_5 q114_6 q116 q118 q120 q121 q122 q123 q126 q127 ///
 q128 q129 q131_17 q133_1 q133_2 q133_3 q133_4 q133_5 q133_6 q133_7 q135_17 q136_1 q137_1 q126_17 q140_1 q141_1 q142_1 q826_16 q831_16 q832 q833 q834_2 q834_3 ///
 q834_4 q834_5 q834_6 q837 q838 q843 q844 q845 q846 q851 q852 q853 q854 q856_17 q858_1 q858_2 q858_3 q858_4 q858_5 q858_6 q858_7 q862_17 q863_1 q864_1 q869_17 ///
 q870_1 q871_1 q872_1 q874_16 q879_16 q880 q881 q882_2 q882_3 q882_4 q882_5 q882_6 q885 q886 q891 q892 q893 q894 q899 q900 q901 q902 q904_17 q906_1 q906_2 q906_3 ///
 q906_4 q906_5 q906_6 q906_7 q910_17 q911_1 q912_1 q917_17 q918_1 q919_1 q920_1 q922_16 q927_16 q928 q929 q930_2 q930_3 q930_4 q930_5 q930_6 q933 q934 q939 q940 ///
 q941 q942 q947 q948 q949 q950 q952_17 q954_1 q954_2 q954_3 q954_4 q954_5 q954_6 q954_7 q958_17 q959_1 q960_1 q965_17 q966_1 q967_1 q968_1 q970_16 q975_16 q976 ///
 q977 q978_2 q978_3 q978_4 q978_5 q978_6 q312 q982 q987 q988 q989 q990 q995 q996 q997 q998 q1000_17 q1002_1 q1002_2 q1002_3 q1002_4 q1002_5 q1002_6 q1002_7 q1006_17 ///
 q1007_1 q1008_1 q1013_17 q1014_1 q1015_1 q1016_1 q1066_16 q1071_16 q1072 q1073 q1074_2 q1074_3 q1074_4 q1074_5 q1074_6 q1077 q1078 q1083 q1084 q1085 q1086 q1091 ///
 q1092 q1093 q1094 q1096_17 q1098_1 q1098_2 q1098_3 q1098_4 q1098_5 q1098_6 q1098_7 q1102_17 q1103_1 q1104_1 q1109_17 q1110_1 q1111_1 q1112_1 q1258_16 q1263_16 ///
 q1264 q1265 q1266_2 q1266_3 q1266_4 q1266_5 q1266_6 q1269 q1270 q1275 q1276 q1277 q1278 q1283 q1284 q1285 q1286 q1288_17 q1290_1 q1290_2 q1290_3 q1290_4 q1290_5 ///
 q1290_6 q1290_7 q1294_17 q1295_1 q1296_1 q1301_17 q1302_1 q1303_1 q1304_1 q1306_16 q1311_16 q1312 q1313 q1314_2 q1314_3 q1314_4 q1314_5 q1314_6 q1317 q1318 ///
 q1323 q1324 q1325 q1326 q1331 q1332 q1333 q1334 q1336_17 q1338_1 q1338_2 q1338_3 q1338_4 q1338_5 q1338_6 q1338_7 q1342_17 q1343_1 q1344_1 q1349_17 q1350_1 ///
 q1351_1 q1352_1 q1354_16 q1359_16 q1360 q1361 q1362_2 q1362_3 q1362_4 q1362_5 q1362_6 q1365 q1366 q1371 q1372 q1373 q1374 q1379 q1380 q1381 q1382 q1384_17 ///
 q1386_1 q1386_2 q1386_3 q1386_4 q1386_5 q1386_6 q1386_7 q1390_17 q1391_1 q1392_1 q1397_17 q1398_1 q1399_1 q1400_1 q1402_16 q1407_16 q1408 q1409 q1410_2 q1410_3 ///
 q1410_4 q1410_5 q1410_6 q1413 q1414 q1419 q1420 q1421 q1422 q1427 q1428 q1429 q1430 q1432_17 q1434_1 q1434_2 q1434_3 q1434_4 q1434_5 q1434_6 q1434_7 q1438_17 ///
 q1439_1 q1440_1 q1445_17 q1446_1 q1447_1 q1448_1 q1450_16 q1455_16 q1456 q1457 q1458_2 q1458_3 q1458_4 q1458_5 q1458_6 q1461 q1462 q1467 q1468 q1469 q1470 q1475 ///
 q1476 q1477 q1478 q1480_17 q1482_1 q1482_2 q1482_3 q1482_4 q1482_5 q1482_6 q1482_7 q1486_17 q1487_1 q1488_1 q1493_17 q1494_1 q1495_1 q1496_1 q1498_16 q1503_16 ///
 q1504 q1505 q1506_2 q1506_3 q1506_4 q1506_5 q1506_6 q1509 q1510 q1515 q1516 q1517 q1518 q1523 q1524 q1525 q1526 q1528_17 q1530_1 q1530_2 q1530_3 q1530_4 q1530_5 ///
 q1530_6 q1530_7 q1534_17 q1535_1 q1536_1 q1541_17 q1542_1 q1543_1 q1544_1 q1738_16 q1743_16 q1744 q1745 q1746_2 q1746_3 q1746_4 q1746_5 q1746_6 q1749 q1750 q1755 ///
 q1756 q1757 q1758 q1763 q1764 q1765 q1766 q1768_17 q1770_1 q1770_2 q1770_3 q1770_4 q1770_5 q1770_6 q1770_7 q1774_17 q1775_1 q1776_1 q1781_17 q1782_1 q1783_1 ///
 q1784_1 q1786_16 q1791_16 q1792 q1793 q1794_2 q1794_3 q1794_4 q1794_5 q1794_6 q1797 q1798 q1803 q1804 q1805 q1806 q1811 q1812 q1813 q1814 q1816_17 q1818_1 ///
 q1818_2 q1818_3 q1818_4 q1818_5 q1818_6 q1818_7 q1822_17 q1823_1 q1824_1 q1829_17 q1830_1 q1831_1 q1832_1 q1834_16 q1839_16 q1840 q1841 q1842_2 q1842_3 q1842_4 ///
 q1842_5 q1842_6 q1845 q1846 q1851 q1852 q1853 q1854 q1859 q1860 q1861 q1862 q1864_17 q1866_1 q1866_2 q1866_3 q1866_4 q1866_5 q1866_6 q1866_7 q1870_17 q1871_1 ///
 q1872_1 q1877_17 q1878_1 q1879_1 q1880_1 q2026_16 q2031_16 q2032 q2033 q2034_2 q2034_3 q2034_4 q2034_5 q2034_6 q2037 q2038 q2043 q2044 q2045 q2046 q2051 q2052 ///
 q2053 q2054 q2056_17 q2058_1 q2058_2 q2058_3 q2058_4 q2058_5 q2058_6 q2058_7 q2062_17 q2063_1 q2064_1 q2069_17 q2070_1 q2071_1 q2072_1 q2074_16 q2079_16 q2080 ///
 q2081 q2082_2 q2082_3 q2082_4 q2082_5 q2082_6 q2085 q2086 q2091 q2092 q2093 q2094 q2099 q2100 q2101 q2102 q2104_17 q2106_1 q2106_2 q2106_3 q2106_4 q2106_5 q2106_6 ///
 q2106_7 q2110_17 q2111_1 q2112_1 q2117_17 q2118_1 q2119_1 q2120_1 q2122_16 q2127_16 q2128 q2129 q2130_2 q2130_3 q2130_4 q2130_5 q2130_6 q2133 q2134 q2139 q2140 ///
 q2141 q2142 q2147 q2148 q2149 q2150 q2152_17 q2154_1 q2154_2 q2154_3 q2154_4 q2154_5 q2154_6 q2154_7 q2158_17 q2159_1 q2160_1 q2165_17 q2166_1 q2167_1 q2168_1 q2314_16 ///
 q2319_16 q2320 q2321 q2322_2 q2322_3 q2322_4 q2322_5 q2322_6 q2325 q2326 q2331 q2332 q2333 q2334 q2339 q2340 q2341 q2342 q2344_17 q2346_1 q2346_2 q2346_3 q2346_4 q2346_5 ///
 q2346_6 q2346_7 q2350_17 q2351_1 q2352_1 q2357_17 q2358_1 q2359_1 q2360_1 q2362_16 q2367_16 q2368 q2369 q2370_2 q2370_3 q2370_4 q2370_5 q2370_6 q2373 q2374 q2379 q2380 ///
 q2381 q2382 q2387 q2388 q2389 q2390 q2392_17 q2394_1 q2394_2 q2394_3 q2394_4 q2394_5 q2394_6 q2394_7 q2398_17 q2399_1 q2400_1 q2405_17 q2406_1 q2407_1 q2408_1 q2410_16 ///
 q2415_16 q2416 q2417 q2418_2 q2418_3 q2418_4 q2418_5 q2418_6 q2421 q2422 q2427 q2428 q2429 q2430 q2435 q2436 q2437 q2438 q2440_17 q2442_1 q2442_2 q2442_3 q2442_4 q2442_5 ///
 q2442_6 q2442_7 q2446_17 q2447_1 q2448_1 q2453_17 q2454_1 q2455_1 q2456_1 q2602_16 q2607_16 q2608 q2609 q2610_2 q2610_3 q2610_4 q2610_5 q2610_6 q2613 q2614 q2619 q2620 ///
 q2621 q2622 q2627 q2628 q2629 q2630 q2632_17 q2634_1 q2634_2 q2634_3 q2634_4 q2634_5 q2634_6 q2634_7 q2638_17 q2639_1 q2640_1 q2645_17 q2646_1 q2647_1 q2648_1 q2650_16 ///
 q2655_16 q2656 q2657 q2658_2 q2658_3 q2658_4 q2658_5 q2658_6 q2661 q2662 q2667 q2668 q2669 q2670 q2675 q2676 q2677 q2678 q2680_17 q2682_1 q2682_2 q2682_3 q2682_4 q2682_5 ///
 q2682_6 q2682_7 q2686_17 q2687_1 q2688_1 q2693_17 q2694_1 q2695_1 q2696_1 q2698_16 q2703_16 q2704 q2705 q2706_2 q2706_3 q2706_4 q2706_5 q2706_6 q2709 q2710 q2715 q2716 ///
 q2717 q2718 q2723 q2724 q2725 q2726 q2728_17 q2730_1 q2730_2 q2730_3 q2730_4 q2730_5 q2730_6 q2730_7 q2734_17 q2735_1 q2736_1 q2741_17 q2742_1 q2743_1 q2744_1 q3178_16 ///
 q3183_16 q3184 q3185 q3186_2 q3186_3 q3186_4 q3186_5 q3186_6 q3189 q3190 q3195 q3196 q3197 q3198 q3203 q3204 q3205 q3206 q3208_17 q3210_1 q3210_2 q3210_3 q3210_4 ///
 q3210_5 q3210_6 q3210_7 q3214_17 q3215_1 q3216_1 q3221_17 q3222_1 q3223_1 q3224_1 q3322_16 q3327_16 q3328 q3329 q3330_2 q3330_3 q3330_4 q3330_5 q3330_6 q3333 q3334 ///
 q3339 q3340 q3341 q3342 q3347 q3348 q3349 q3350 q3352_17 q3354_1 q3354_2 q3354_3 q3354_4 q3354_5 q3354_6 q3354_7 q3358_17 q3359_1 q3360_1 q3365_17 q3366_1 q3367_1 ///
 q3368_1 q3370_16 q3375_16 q3376 q3377 q3378_2 q3378_3 q3378_4 q3378_5 q3378_6 q3381 q3382 q3387 q3388 q3389 q3390 q3395 q3396 q3397 q3398 q3400_17 q3402_1 q3402_2 ///
 q3402_3 q3402_4 q3402_5 q3402_6 q3402_7 q3406_17 q3407_1 q3408_1 q3413_17 q3414_1 q3415_1 q3416_1 q3418_16 q3423_16 q3424 q3425 q3426_2 q3426_3 q3426_4 q3426_5 ///
 q3426_6 q3429 q3430 q3435 q3436 q3437 q3438 q3443 q3444 q3445 q3446 q3448_17 q3450_1 q3450_2 q3450_3 q3450_4 q3450_5 q3450_6 q3450_7 q3454_17 q3455_1 q3456_1 ///
 q3461_17 q3462_1 q3463_1 q3464_1 q3514_16 q3519_16 q3520 q3521 q3522_2 q3522_3 q3522_4 q3522_5 q3522_6 q3525 q3526 q3531 q3532 q3533 q3534 q3539 q3540 q3541 ///
 q3542 q3544_17 q3546_1 q3546_2 q3546_3 q3546_4 q3546_5 q3546_6 q3546_7 q3550_17 q3551_1 q3552_1 q3557_17 q3558_1 q3559_1 q3560_1 q2890_16 q2895_16 q2896 q2897 q2898_2 ///
 q2898_3 q2898_4 q2898_5 q2898_6 q2901 q2902 q2907 q2908 q2909 q2910 q2915 q2916 q2917 q2918 q2920_17 q2922_1 q2922_2 q2922_3 q2922_4 q2922_5 q2922_6 q2922_7 q2926_17 ///
 q2927_1 q2928_1 q2933_17 q2934_1 q2935_1 q2936_1 q2938_16 q2943_16 q2944 q2945 q2946_2 q2946_3 q2946_4 q2946_5 q2946_6 q2949 q2950 q2955 q2956 q2957 q2958 q2963 q2964 ///
 q2965 q2968_17 q2970_1 q2970_2 q2970_3 q2970_4 q2970_5 q2970_6 q2970_7 q2974_17 q2975_1 q2976_1 q2981_17 q2982_1 q2983_1 q2984_1 q2986_16 q2991_16 q2992 q2993 q2994_2 ///
 q2994_3 q2994_4 q2994_5 q2994_6 q2997 q2998 q3003 q3004 q3005 q3006 q3011 q3012 q3013 q3014 q3016_17 q3018_1 q3018_2 q3018_3 q3018_4 q3018_5 q3018_6 q3018_7 q3022_17 ///
 q3023_1 q3024_1 q3029_17 q3030_1 q3031_1 q3032_1 end_time q8 q9 consent q2 q2_text q5 q6 q3 start_time ///
 q43 q7989 q8000 q8001 q8002 q8003 q8004 q38 q8012 q37 q8018 q42 q8023 q8027 q38_2 q8030 q39 q174 q36_1 q36_2 q36_3 q36_4 q29 q129_1 q176 q175 q177 q128_text q25 q25_text q26 q27 q28 q7949edu

////////////////////////////////////////////////////////////////
// PART 12:  
// SAVE FINAL DATASET READY FOR MERGING WITH DONORS 
///////////////////////////////////////////////////////////////

compress
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Data for Analysis"
save Mass_Public_Cleaned.dta, replace



