// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018

// This code assess balance on treatment variables for the donors and mass
// The experiments were conducted seperately, and therefore, we include an assessment of balance for each.
// We run a multinominal logit regression predicting treatment assignment using the same demographic and partisan covariates as our regression models. We then run an F-test jointly testing the covariates
// We also present means and standard devaitions for each covariate
set more off
clear
use Data\mass_and_donor_experiments_FINAL


// DONORS ONLY //

//creates dependent variable for multinomial logit
gen group_num = .
replace group_num = 1 if group =="Aligned" // group is a var only for donors
replace group_num = 2 if group =="Extreme"
replace group_num = 3 if group =="Bipartisan"

// f test + means and Standard Deviations
mlogit group_num strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus if donor_d==1
testparm strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus // .5455 p value
local ftest = r(p)

outsum strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus if group_num==1 & donor_d==1 using "Balance_MeansSDs_Donors.out" , replace ctitle ("Aligned") bracket addnote("F test p value: `ftest'" )

outsum strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus  if group_num==2 & donor_d==1 using "Balance_MeansSDs_Donors.out" , append ctitle ("Extreme") bracket addnote("F test p value: `ftest'" ) 

outsum strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus  if group_num==3 & donor_d==1 using "Balance_MeansSDs_Donors.out" , append ctitle ("Bipartisan") bracket addnote("F test p value: `ftest'" ) 

// MASS PUBLIC ONLY //
// need a dependent var
gen group_num_mass = .
replace group_num_mass = 1 if T_Aligned ==1 // covers both donors and masses
replace group_num_mass = 2 if T_Extreme ==1
replace group_num_mass = 3 if T_Bipartisan ==1

// if condition models only mass public for logit and means/SDs
// f test + means and Standard Deviations
mlogit group_num_mass strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus if donor_d==0
testparm strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus // .14 p value
local ftest = r(p)

outsum strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus if group_num_mass==1 & donor_d==0 using "Balance_MeansSDs_Mass.out" , replace ctitle ("Aligned") bracket addnote("F test p value: `ftest'" )

outsum strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus  if group_num_mass==2 & donor_d==0 using "Balance_MeansSDs_Mass.out" , append ctitle ("Extreme") bracket addnote("F test p value: `ftest'" ) 

outsum strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus  if group_num_mass==3 & donor_d==0 using "Balance_MeansSDs_Mass.out" , append ctitle ("Bipartisan") bracket addnote("F test p value: `ftest'" ) 

